==> moon-0.7.tar.bz2: moon-0.7/class/System.Windows/System.Windows.Media.Animation/ColorKeyFrameCollection.cs <==
// Author:
//   Chris Toshok  (toshok@ximian.com)
//
// Copyright 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using Mono;
using System.Windows;

namespace System.Windows.Media.Animation
{
	public sealed class ColorKeyFrameCollection : PresentationFrameworkCollection<ColorKeyFrame> {
		public ColorKeyFrameCollection () : base (NativeMethods.color_key_frame_collection_new ())
		{
		}

		internal ColorKeyFrameCollection (IntPtr raw) : base (raw)
		{
		}

		internal override Kind GetKind ()
		{
			return Kind.COLORKEYFRAME_COLLECTION;
		}
	}
}

==> moon-1.0.1.tar.bz2: moon-1.0.1/class/System.Windows/System.Windows.Media.Animation/ColorKeyFrameCollection.cs <==
// Contact:
//   Moonlight List (moonlight-list@lists.ximian.com)
//
// Copyright 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using Mono;
using System.Windows;

namespace System.Windows.Media.Animation
{
	public sealed partial class ColorKeyFrameCollection : PresentationFrameworkCollection<ColorKeyFrame> {

		public override void Add (ColorKeyFrame value)
		{
			AddImpl (value);
		}
		
		public override bool Contains (ColorKeyFrame value)
		{
			return ContainsImpl (value);
		}
		
		public override int IndexOf (ColorKeyFrame value)
		{
			return IndexOfImpl (value);
		}
		
		public override void Insert (int index, ColorKeyFrame value)
		{
			InsertImpl (index, value);
		}
		
		public override bool Remove (ColorKeyFrame value)
		{
			return RemoveImpl (value);
		}
		
		public override ColorKeyFrame this[int index] {
			get { return GetItemImpl (index); }
			set { SetItemImpl (index, value); }
		}
	}
}
